@@ -29,6 +29,7 @@ from meilisearch.models.index import (
     Faceting,
     HuggingFaceEmbedder,
     IndexStats,
+    LocalizedAttributes,
     OpenAiEmbedder,
     Pagination,
     ProximityPrecision,
@@ -280,12 +281,7 @@ class Index:
             String containing the searched word(s)
         opt_params (optional):
             Dictionary containing optional query parameters.
-            Note: The vector parameter is only available in Meilisearch >= v1.3.0, and is experimental
-            Meilisearch v1.3.0. In order to use this feature in Meilisearch v1.3.0 you first need to
-            enable the feature by sending a PATCH request to /experimental-features with
-            { "vectoreStore": true }. Because this feature is experimental it may be removed or
-            updated causing breaking changes in this library without a major version bump so use
-            with caution.
+            Note: The vector parameter is only available in Meilisearch >= v1.13.0
             https://www.meilisearch.com/docs/reference/api/search#search-in-an-index
 
         Returns
@@ -405,6 +401,30 @@ class Index:
         )
         return DocumentsResults(response)
 
+    def get_similar_documents(self, parameters: Mapping[str, Any]) -> Dict[str, Any]:
+        """Get the documents similar to a document.
+
+        Parameters
+        ----------
+        parameters:
+            parameters accepted by the get similar documents route: https://www.meilisearch.com/docs/reference/api/similar#body
+            "id" and "embedder" are required.
+
+        Returns
+        -------
+        results:
+            Dictionary with hits, offset, limit, processingTimeMs, and id
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        return self.http.post(
+            f"{self.config.paths.index}/{self.uid}/{self.config.paths.similar}",
+            body=parameters,
+        )
+
     def add_documents(
         self,
         documents: Sequence[Mapping[str, Any]],
@@ -2042,6 +2062,73 @@ class Index:
 
         return TaskInfo(**task)
 
+    # LOCALIZED ATTRIBUTES SETTINGS
+
+    def get_localized_attributes(self) -> Union[List[LocalizedAttributes], None]:
+        """Get the localized_attributes of the index.
+
+        Returns
+        -------
+        settings:
+            localized_attributes of the index.
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        response = self.http.get(self.__settings_url_for(self.config.paths.localized_attributes))
+
+        if not response:
+            return None
+
+        return [LocalizedAttributes(**attrs) for attrs in response]
+
+    def update_localized_attributes(
+        self, body: Union[List[Mapping[str, List[str]]], None]
+    ) -> TaskInfo:
+        """Update the localized_attributes of the index.
+
+        Parameters
+        ----------
+        body:
+            localized_attributes
+
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        task = self.http.put(self.__settings_url_for(self.config.paths.localized_attributes), body)
+
+        return TaskInfo(**task)
+
+    def reset_localized_attributes(self) -> TaskInfo:
+        """Reset the localized_attributes of the index
+
+        Returns
+        -------
+        task_info:
+            TaskInfo instance containing information about a task to track the progress of an asynchronous process.
+            https://www.meilisearch.com/docs/reference/api/tasks#get-one-task
+
+        Raises
+        ------
+        MeilisearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://www.meilisearch.com/docs/reference/errors/error_codes#meilisearch-errors
+        """
+        task = self.http.delete(
+            self.__settings_url_for(self.config.paths.localized_attributes),
+        )
+
+        return TaskInfo(**task)
+
     @staticmethod
     def _batch(
         documents: Sequence[Mapping[str, Any]], batch_size: int
